[master] Imported from libpng-1.4.1beta11.tar
diff --git a/CMakeLists.txt b/CMakeLists.txt
index eb34f63..85598dd 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -209,7 +209,7 @@
 # SET UP LINKS
 if(PNG_SHARED)
   set_target_properties(${PNG_LIB_NAME} PROPERTIES
-#   VERSION 14.${PNGLIB_RELEASE}.1.4.1beta10
+#   VERSION 14.${PNGLIB_RELEASE}.1.4.1beta11
     VERSION 14.${PNGLIB_RELEASE}.0
     SOVERSION 14
     CLEAN_DIRECT_OUTPUT 1)
diff --git a/INSTALL b/INSTALL
index a0fc4cf..adfe080 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
 
-Installing libpng version 1.4.1beta10 - February 8, 2010
+Installing libpng version 1.4.1beta11 - February 13, 2010
 
 On Unix/Linux and similar systems, you can simply type
 
@@ -46,7 +46,7 @@
 correspond to the version of zlib that's installed.
 
 You can rename the directories that you downloaded (they
-might be called "libpng-1.4.1beta10" or "libpng14" and "zlib-1.2.3"
+might be called "libpng-1.4.1beta11" or "libpng14" and "zlib-1.2.3"
 or "zlib123") so that you have directories called "zlib" and "libpng".
 
 Your directory structure should look like this:
diff --git a/LICENSE b/LICENSE
index 954bb12..c9b7026 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.4.1beta10, February 8, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.1beta11, February 13, 2010, are
 Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-February 8, 2010
+February 13, 2010
diff --git a/Makefile.am b/Makefile.am
index c0abfa3..9dbac31 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -73,7 +73,7 @@
 	${srcdir}/contrib/pngsuite/* \
 	${srcdir}/contrib/visupng/* \
 	$(TESTS) \
-	example.c libpng-1.4.1beta10.txt
+	example.c libpng-1.4.1beta11.txt
 
 CLEANFILES= pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
 libpng.sym
diff --git a/Makefile.in b/Makefile.in
index 6bd161e..2012d6e 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -333,7 +333,7 @@
 	${srcdir}/contrib/pngsuite/* \
 	${srcdir}/contrib/visupng/* \
 	$(TESTS) \
-	example.c libpng-1.4.1beta10.txt
+	example.c libpng-1.4.1beta11.txt
 
 CLEANFILES = pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
 libpng.sym
diff --git a/README b/README
index d8b4d5b..fa3d994 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.4.1beta10 - February 8, 2010 (shared library 14.0)
+README for libpng version 1.4.1beta11 - February 13, 2010 (shared library 14.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
@@ -185,9 +185,9 @@
        makefile.std     =>  Generic UNIX makefile (cc, creates static
                             libpng.a)
        makefile.elf     =>  Linux/ELF makefile symbol versioning,
-                            gcc, creates libpng14.so.14.1.4.1beta10)
+                            gcc, creates libpng14.so.14.1.4.1beta11)
        makefile.linux   =>  Linux/ELF makefile
-                            (gcc, creates libpng14.so.14.1.4.1beta10)
+                            (gcc, creates libpng14.so.14.1.4.1beta11)
        makefile.gcc     =>  Generic makefile (gcc, creates static libpng.a)
        makefile.knr     =>  Archaic UNIX Makefile that converts files with
                             ansi2knr (Requires ansi2knr.c from
@@ -209,12 +209,12 @@
        makefile.openbsd =>  OpenBSD makefile
        makefile.sgi     =>  Silicon Graphics IRIX (cc, creates static lib)
        makefile.sggcc   =>  Silicon Graphics
-                            (gcc, creates libpng14.so.14.1.4.1beta10)
+                            (gcc, creates libpng14.so.14.1.4.1beta11)
        makefile.sunos   =>  Sun makefile
        makefile.solaris =>  Solaris 2.X makefile
-                            (gcc, creates libpng14.so.14.1.4.1beta10)
+                            (gcc, creates libpng14.so.14.1.4.1beta11)
        makefile.so9     =>  Solaris 9 makefile
-                            (gcc, creates libpng14.so.14.1.4.1beta10)
+                            (gcc, creates libpng14.so.14.1.4.1beta11)
        makefile.32sunu  =>  Sun Ultra 32-bit makefile
        makefile.64sunu  =>  Sun Ultra 64-bit makefile
        makefile.sco     =>  For SCO OSr5  ELF and Unixware 7 with Native cc
diff --git a/configure b/configure
index a43dc8c..b494a19 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.65 for libpng 1.4.1beta10.
+# Generated by GNU Autoconf 2.65 for libpng 1.4.1beta11.
 #
 # Report bugs to <png-mng-implement@lists.sourceforge.net>.
 #
@@ -701,8 +701,8 @@
 # Identity of this package.
 PACKAGE_NAME='libpng'
 PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.4.1beta10'
-PACKAGE_STRING='libpng 1.4.1beta10'
+PACKAGE_VERSION='1.4.1beta11'
+PACKAGE_STRING='libpng 1.4.1beta11'
 PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
 PACKAGE_URL=''
 
@@ -1432,7 +1432,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures libpng 1.4.1beta10 to adapt to many kinds of systems.
+\`configure' configures libpng 1.4.1beta11 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1502,7 +1502,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of libpng 1.4.1beta10:";;
+     short | recursive ) echo "Configuration of libpng 1.4.1beta11:";;
    esac
   cat <<\_ACEOF
 
@@ -1607,7 +1607,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-libpng configure 1.4.1beta10
+libpng configure 1.4.1beta11
 generated by GNU Autoconf 2.65
 
 Copyright (C) 2009 Free Software Foundation, Inc.
@@ -2032,7 +2032,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by libpng $as_me 1.4.1beta10, which was
+It was created by libpng $as_me 1.4.1beta11, which was
 generated by GNU Autoconf 2.65.  Invocation command line was
 
   $ $0 $@
@@ -2840,7 +2840,7 @@
 
 # Define the identity of the package.
  PACKAGE='libpng'
- VERSION='1.4.1beta10'
+ VERSION='1.4.1beta11'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -2904,7 +2904,7 @@
 
 
 
-PNGLIB_VERSION=1.4.1beta10
+PNGLIB_VERSION=1.4.1beta11
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=4
 PNGLIB_RELEASE=1
@@ -12027,7 +12027,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by libpng $as_me 1.4.1beta10, which was
+This file was extended by libpng $as_me 1.4.1beta11, which was
 generated by GNU Autoconf 2.65.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -12093,7 +12093,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-libpng config.status 1.4.1beta10
+libpng config.status 1.4.1beta11
 configured by $0, generated by GNU Autoconf 2.65,
   with options \\"\$ac_cs_config\\"
 
diff --git a/configure.ac b/configure.ac
index fa4a5d4..fa826a9 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,12 +18,12 @@
 
 dnl Version number stuff here:
 
-AC_INIT([libpng], [1.4.1beta10], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.4.1beta11], [png-mng-implement@lists.sourceforge.net])
 AM_INIT_AUTOMAKE
 dnl stop configure from automagically running automake
 AM_MAINTAINER_MODE
 
-PNGLIB_VERSION=1.4.1beta10
+PNGLIB_VERSION=1.4.1beta11
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=4
 PNGLIB_RELEASE=1
diff --git a/libpng-1.4.1beta10.txt b/libpng-1.4.1beta11.txt
similarity index 99%
rename from libpng-1.4.1beta10.txt
rename to libpng-1.4.1beta11.txt
index e7a741c..e2350f2 100644
--- a/libpng-1.4.1beta10.txt
+++ b/libpng-1.4.1beta11.txt
@@ -1,6 +1,6 @@
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.4.1beta10 - February 8, 2010
+ libpng version 1.4.1beta11 - February 13, 2010
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.4.1beta10 - February 8, 2010
+ libpng versions 0.97, January 1998, through 1.4.1beta11 - February 13, 2010
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
 
@@ -899,7 +899,7 @@
 As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
 added.  It expands the sample depth without changing tRNS to alpha.
 
-As of libpng version 1.4.1beta10, not all possible expansions are supported.
+As of libpng version 1.4.1beta11, not all possible expansions are supported.
 
 In the following table, the 01 means grayscale with depth<8, 31 means
 indexed with depth<8, other numerals represent the color type, "T" means
@@ -3245,13 +3245,13 @@
 
 XIII. Y2K Compliance in libpng
 
-February 8, 2010
+February 13, 2010
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.1beta10 are Y2K compliant.  It is my belief that earlier
+upward through 1.4.1beta11 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index 5b43685..e4d7571 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "February 8, 2010"
+.TH LIBPNG 3 "February 13, 2010"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.1beta10
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.1beta11
 .SH SYNOPSIS
 \fI\fB
 
@@ -785,7 +785,7 @@
 .SH LIBPNG.TXT
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.4.1beta10 - February 8, 2010
+ libpng version 1.4.1beta11 - February 13, 2010
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -796,7 +796,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.4.1beta10 - February 8, 2010
+ libpng versions 0.97, January 1998, through 1.4.1beta11 - February 13, 2010
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
 
@@ -1684,7 +1684,7 @@
 As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
 added.  It expands the sample depth without changing tRNS to alpha.
 
-As of libpng version 1.4.1beta10, not all possible expansions are supported.
+As of libpng version 1.4.1beta11, not all possible expansions are supported.
 
 In the following table, the 01 means grayscale with depth<8, 31 means
 indexed with depth<8, other numerals represent the color type, "T" means
@@ -4030,13 +4030,13 @@
 
 .SH XIII. Y2K Compliance in libpng
 
-February 8, 2010
+February 13, 2010
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.1beta10 are Y2K compliant.  It is my belief that earlier
+upward through 1.4.1beta11 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
@@ -4267,7 +4267,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.4.1beta10 - February 8, 2010:
+Libpng version 1.4.1beta11 - February 13, 2010:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -4290,7 +4290,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.4.1beta10, February 8, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.1beta11, February 13, 2010, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -4389,7 +4389,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-February 8, 2010
+February 13, 2010
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 9751985..5881cb6 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "February 8, 2010"
+.TH LIBPNGPF 3 "February 13, 2010"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.1beta10
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.1beta11
 (private functions)
 .SH SYNOPSIS
 \fB#include <png.h>\fP
diff --git a/png.5 b/png.5
index 529c92e..26f62e4 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "February 8, 2010"
+.TH PNG 5 "February 13, 2010"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/pngconf.h b/pngconf.h
index 634ca74..b49113b 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.4.1beta10 - February 8, 2010
+ * libpng version 1.4.1beta11 - February 13, 2010
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngget.c b/pngget.c
index d56dc6f..ca73e7f 100644
--- a/pngget.c
+++ b/pngget.c
@@ -1,7 +1,7 @@
 
 /* pngget.c - retrieval of values from info struct
  *
- * Last changed in libpng 1.4.1 [February 8, 2010]
+ * Last changed in libpng 1.4.1 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngmem.c b/pngmem.c
index b8a5375..0ea1c61 100644
--- a/pngmem.c
+++ b/pngmem.c
@@ -1,7 +1,7 @@
 
 /* pngmem.c - stub functions for memory allocation
  *
- * Last changed in libpng 1.4.0 [February 8, 2010]
+ * Last changed in libpng 1.4.0 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngpread.c b/pngpread.c
index f9bb22a..18cbf88 100644
--- a/pngpread.c
+++ b/pngpread.c
@@ -1,7 +1,7 @@
 
 /* pngpread.c - read a png file in push mode
  *
- * Last changed in libpng 1.4.1 [February 8, 2010]
+ * Last changed in libpng 1.4.1 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngpriv.h b/pngpriv.h
index 7fb9c7d..98e8313 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
 
 /* pngpriv.h - private declarations for use inside libpng
  *
- * libpng version 1.4.1beta10 - February 8, 2010
+ * libpng version 1.4.1beta11 - February 13, 2010
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -306,8 +306,6 @@
 /* Decompress data in a chunk that uses compression */
 #if defined(PNG_zTXt_SUPPORTED) || defined(PNG_iTXt_SUPPORTED) || \
     defined(PNG_iCCP_SUPPORTED) || defined(PNG_sPLT_SUPPORTED)
-PNG_EXTERN png_size_t png_measure_decompressed_chunk PNGARG((png_structp
-    png_ptr, int comp_type, png_size_t chunklength, png_size_t prefix_length));
 PNG_EXTERN void png_decompress_chunk PNGARG((png_structp png_ptr,
    int comp_type, png_size_t chunklength, png_size_t prefix_length,
    png_size_t *data_length));
diff --git a/pngread.c b/pngread.c
index 148c3ef..815b628 100644
--- a/pngread.c
+++ b/pngread.c
@@ -1,7 +1,7 @@
 
 /* pngread.c - read a PNG file
  *
- * Last changed in libpng 1.4.1 [February 8, 2010]
+ * Last changed in libpng 1.4.1 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrio.c b/pngrio.c
index 80457e4..5f115b1 100644
--- a/pngrio.c
+++ b/pngrio.c
@@ -1,7 +1,7 @@
 
 /* pngrio.c - functions for data input
  *
- * Last changed in libpng 1.4.1 [February 8, 2010]
+ * Last changed in libpng 1.4.1 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrtran.c b/pngrtran.c
index e3a6472..c8b438c 100644
--- a/pngrtran.c
+++ b/pngrtran.c
@@ -1,7 +1,7 @@
 
 /* pngrtran.c - transforms the data in a row for PNG readers
  *
- * Last changed in libpng 1.4.1 [February 8, 2010]
+ * Last changed in libpng 1.4.1 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngset.c b/pngset.c
index d7a1434..4cb58b8 100644
--- a/pngset.c
+++ b/pngset.c
@@ -1,7 +1,7 @@
 
 /* pngset.c - storage of image information into info struct
  *
- * Last changed in libpng 1.4.1 [February 8, 2010]
+ * Last changed in libpng 1.4.1 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngtest.c b/pngtest.c
index c909059..93730a1 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1,7 +1,7 @@
 
 /* pngtest.c - a simple test program to test libpng
  *
- * Last changed in libpng 1.4.1 [February 8, 2010]
+ * Last changed in libpng 1.4.1 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -1627,4 +1627,4 @@
 }
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_1beta10 your_png_h_is_not_version_1_4_1beta10;
+typedef version_1_4_1beta11 your_png_h_is_not_version_1_4_1beta11;
diff --git a/pngwtran.c b/pngwtran.c
index e5be4fd..f7a0ef4 100644
--- a/pngwtran.c
+++ b/pngwtran.c
@@ -1,7 +1,7 @@
 
 /* pngwtran.c - transforms the data in a row for PNG writers
  *
- * Last changed in libpng 1.4.1 [February 8, 2010]
+ * Last changed in libpng 1.4.1 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwutil.c b/pngwutil.c
index 740b116..ff497a1 100644
--- a/pngwutil.c
+++ b/pngwutil.c
@@ -1,7 +1,7 @@
 
 /* pngwutil.c - utilities to write a PNG file
  *
- * Last changed in libpng 1.4.1 [February 8, 2010]
+ * Last changed in libpng 1.4.1 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/projects/cbuilder5/README.txt b/projects/cbuilder5/README.txt
deleted file mode 100644
index 9efaa4b..0000000
--- a/projects/cbuilder5/README.txt
+++ /dev/null
@@ -1,11 +0,0 @@
-The cbuilder5 project has not been updated to libpng-1.4.0.
-
-It needs to depend on pngpriv.h
-
-It needs to *not* depend on pnggccrd.c or pngvcrd.c
-
-It needs to DEFINE PNG_NO_PEDANTIC_WARNING while building
-the library, but not while building an application.
-
-If an updated version is not received, this project will
-be removed when libpng-1.4.0 is released.
diff --git a/projects/cbuilder5/libpng.bpf b/projects/cbuilder5/libpng.bpf
deleted file mode 100644
index ee6d929..0000000
--- a/projects/cbuilder5/libpng.bpf
+++ /dev/null
@@ -1,22 +0,0 @@
-USEUNIT("libpng.cpp");

-USEUNIT("..\..\png.c");

-USEUNIT("..\..\pngerror.c");

-USEUNIT("..\..\pngget.c");

-USEUNIT("..\..\pngmem.c");

-USEUNIT("..\..\pngpread.c");

-USEUNIT("..\..\pngread.c");

-USEUNIT("..\..\pngrio.c");

-USEUNIT("..\..\pngrtran.c");

-USEUNIT("..\..\pngrutil.c");

-USEUNIT("..\..\pngset.c");

-USEUNIT("..\..\pngtrans.c");

-USEUNIT("..\..\pngwio.c");

-USEUNIT("..\..\pngwrite.c");

-USEUNIT("..\..\pngwtran.c");

-USEUNIT("..\..\pngwutil.c");

-USELIB("..\..\..\zlib\zlib.lib");

-//---------------------------------------------------------------------------

-This file is used by the project manager only and should be treated like the project file

-

-

-DllEntryPoint

diff --git a/projects/cbuilder5/libpng.bpg b/projects/cbuilder5/libpng.bpg
deleted file mode 100644
index c6c6a4e..0000000
--- a/projects/cbuilder5/libpng.bpg
+++ /dev/null
@@ -1,25 +0,0 @@
-#------------------------------------------------------------------------------

-VERSION = BWS.01

-#------------------------------------------------------------------------------

-!ifndef ROOT

-ROOT = $(MAKEDIR)\..

-!endif

-#------------------------------------------------------------------------------

-MAKE = $(ROOT)\bin\make.exe -$(MAKEFLAGS) -f$**

-DCC = $(ROOT)\bin\dcc32.exe $**

-BRCC = $(ROOT)\bin\brcc32.exe $**

-#------------------------------------------------------------------------------

-PROJECTS = libpngstat.lib libpng.dll

-#------------------------------------------------------------------------------

-default: $(PROJECTS)

-#------------------------------------------------------------------------------

-

-libpngstat.lib: libpngstat.bpr

-  $(ROOT)\bin\bpr2mak -t$(ROOT)\bin\deflib.bmk $**

-  $(ROOT)\bin\make -$(MAKEFLAGS) -f$*.mak

-

-libpng.dll: libpng.bpr

-  $(ROOT)\bin\bpr2mak $**

-  $(ROOT)\bin\make -$(MAKEFLAGS) -f$*.mak

-

-

diff --git a/projects/cbuilder5/libpng.bpr b/projects/cbuilder5/libpng.bpr
deleted file mode 100644
index 7e09dda..0000000
--- a/projects/cbuilder5/libpng.bpr
+++ /dev/null
@@ -1,157 +0,0 @@
-<?xml version='1.0' encoding='utf-8' ?>

-<!-- C++Builder XML Project -->

-<PROJECT>

-  <MACROS>

-    <VERSION value="BCB.05.03"/>

-    <PROJECT value="libpng.dll"/>

-    <OBJFILES value="libpng.obj ..\..\pngwutil.obj ..\..\pngerror.obj ..\..\pngget.obj 

-      ..\..\pngmem.obj ..\..\pngpread.obj ..\..\pngread.obj ..\..\pngrio.obj 

-      ..\..\pngrtran.obj ..\..\pngrutil.obj ..\..\pngset.obj ..\..\pngtrans.obj 

-      ..\..\pngwio.obj ..\..\pngwrite.obj ..\..\pngwtran.obj ..\..\png.obj"/>

-    <RESFILES value=""/>

-    <DEFFILE value=""/>

-    <RESDEPEN value="$(RESFILES)"/>

-    <LIBFILES value="..\..\..\zlib\zlib.lib"/>

-    <LIBRARIES value="bcbsmp50.lib dclocx50.lib NMFast50.lib Tee50.lib Vclx50.lib Vcl50.lib"/>

-    <SPARELIBS value="Vcl50.lib Vclx50.lib Tee50.lib NMFast50.lib dclocx50.lib bcbsmp50.lib"/>

-    <PACKAGES value="Vcl50.bpi Vclx50.bpi bcbsmp50.bpi Qrpt50.bpi Vcldb50.bpi Vclbde50.bpi 

-      ibsmp50.bpi vcldbx50.bpi TeeUI50.bpi TeeDB50.bpi Tee50.bpi TeeQR50.bpi 

-      VCLIB50.bpi bcbie50.bpi vclie50.bpi Inetdb50.bpi Inet50.bpi NMFast50.bpi 

-      dclocx50.bpi bcb97axserver50.bpi SIMULUSCOMPONENTS.bpi Simulus2.bpi"/>

-    <PATHCPP value=".;..\.."/>

-    <PATHPAS value=".;"/>

-    <PATHRC value=".;"/>

-    <PATHASM value=".;"/>

-    <DEBUGLIBPATH value="$(BCB)\lib\debug"/>

-    <RELEASELIBPATH value="$(BCB)\lib\release"/>

-    <LINKER value="tlink32"/>

-    <USERDEFINES value="PNG_BUILD_DLL;PNG_NO_MODULEDEF"/>

-    <SYSDEFINES value="NO_STRICT;_NO_VCL;_RTLDLL"/>

-    <MAINSOURCE value="libpng.bpf"/>

-    <INCLUDEPATH value="..\..;..\..\..\zlib;$(BCB)\include"/>

-    <LIBPATH value="..\..;$(BCB)\lib\obj;$(BCB)\lib"/>

-    <WARNINGS value="-w8092 -w8091 -w8090 -w8089 -w8087 -wprc -wucp -wstv -wstu -wsig -wpin 

-      -wnod -wnak -wdef -wcln -wbbf -wasm -wamp -wamb"/>

-  </MACROS>

-  <OPTIONS>

-    <CFLAG1 value="-WD -O2 -w -Vx -Ve -x- -RT- -X- -a8 -5 -b- -d -k- -vi -tWD -tWM -c"/>

-    <PFLAGS value="-$Y- -$L- -$D- -$C- -v -JPHNE -M"/>

-    <RFLAGS value=""/>

-    <AFLAGS value="/mx /w2 /zn"/>

-    <LFLAGS value="-D&quot;&quot; -aa -Tpd -x -Gn -Gi -w"/>

-  </OPTIONS>

-  <LINKER>

-    <ALLOBJ value="c0d32.obj $(OBJFILES)"/>

-    <ALLRES value="$(RESFILES)"/>

-    <ALLLIB value="$(LIBFILES) $(LIBRARIES) import32.lib cw32mti.lib"/>

-  </LINKER>

-  <IDEOPTIONS>

-[Version Info]

-IncludeVerInfo=0

-AutoIncBuild=0

-MajorVer=1

-MinorVer=0

-Release=0

-Build=0

-Debug=0

-PreRelease=0

-Special=0

-Private=0

-DLL=1

-Locale=2057

-CodePage=1252

-

-[Version Info Keys]

-CompanyName=

-FileDescription=

-FileVersion=1.0.0.0

-InternalName=

-LegalCopyright=

-LegalTrademarks=

-OriginalFilename=

-ProductName=

-ProductVersion=

-Comments=

-

-[HistoryLists\hlIncludePath]

-Count=18

-Item0=..\..;..\..\..\zlib;$(BCB)\include

-Item1=..\..;P:\My Documents\Source\PNG+ZLib\zlib;$(BCB)\include

-Item2=..\..;..\Source\ThirdParty\PortableNetworkGraphics\external;..\Source\ThirdParty\PortableNetworkGraphics;..\Source\ThirdParty\ZLibCompression\external;$(BCB)\include

-Item3=..\Source\ThirdParty\PortableNetworkGraphics\external;..\Source\ThirdParty\PortableNetworkGraphics;..\Source\ThirdParty\ZLibCompression\external;$(BCB)\include

-Item4=..\Source\ThirdParty\PortableNetworkGraphics\external;..\Source\ThirdParty\PortableNetworkGraphics;..\Source\ThirdParty\ZLibCompression;$(BCB)\include

-Item5=..\Source\ThirdParty\PortableNetworkGraphics;..\Source\ThirdParty\ZLibCompression;$(BCB)\include

-Item6=..\Source\ThirdParty\PortableNetworkGraphics;P:\Development\Source\ThirdParty\ZLibCompression;$(BCB)\include

-Item7=..\Source\ThirdParty\PortableNetworkGraphics;$(BCB)\include

-Item8=$(BCB)\include

-Item9=..\Source;..\Source\General\Templates;..\Source\SIMUtilities;$(BCB)\include;$(BCB)\include\vcl

-Item10=P:\Development\Source\;P:\Development\Source\General\Templates\;P:\Development\Source\SIMUtilities\;$(BCB)\include;$(BCB)\include\vcl

-Item11=P:\Development\Source;P:\Development\Source\General\Templates\;P:\Development\Source\SIMUtilities\;$(BCB)\include;$(BCB)\include\vcl

-Item12=P:\Development\Source\General\Templates\;P:\Development\Source\SIMUtilities\;$(BCB)\include;$(BCB)\include\vcl

-Item13=P:\Development\Source\General\Templates\;P:\Development\Source\SIMUtilities;$(BCB)\include;$(BCB)\include\vcl

-Item14=P:\Development\Source\General\Templates\;$(BCB)\include;$(BCB)\include\vcl

-Item15=P:\Development\Source\General\Templates;$(BCB)\include;$(BCB)\include\vcl

-Item16=P:\Development\Source;$(BCB)\include;$(BCB)\include\vcl

-Item17=$(BCB)\include;$(BCB)\include\vcl

-

-[HistoryLists\hlLibraryPath]

-Count=10

-Item0=..\..;$(BCB)\lib\obj;$(BCB)\lib

-Item1=..\..;..\Source\ThirdParty\PortableNetworkGraphics\external;..\Source\ThirdParty\PortableNetworkGraphics;$(BCB)\lib\obj;$(BCB)\lib

-Item2=..\Source\ThirdParty\PortableNetworkGraphics\external;..\Source\ThirdParty\PortableNetworkGraphics;$(BCB)\lib\obj;$(BCB)\lib

-Item3=..\Source\ThirdParty\PortableNetworkGraphics;$(BCB)\lib\obj;$(BCB)\lib

-Item4=$(BCB)\lib\obj;$(BCB)\lib

-Item5=..\Source\SIMUtilities;..\Source;$(BCB)\lib\obj;$(BCB)\lib

-Item6=P:\Development\Source\SIMUtilities\;P:\Development\Source\;$(BCB)\lib\obj;$(BCB)\lib

-Item7=P:\Development\Source\SIMUtilities;P:\Development\Source\;$(BCB)\lib\obj;$(BCB)\lib

-Item8=P:\Development\Source\;$(BCB)\lib\obj;$(BCB)\lib

-Item9=P:\Development\Source;$(BCB)\lib\obj;$(BCB)\lib

-

-[HistoryLists\hlDebugSourcePath]

-Count=1

-Item0=$(BCB)\source\vcl

-

-[HistoryLists\hlConditionals]

-Count=20

-Item0=ZLIB_DLL;Z_PREFIX;PNG_BUILD_DLL;PNG_NO_MODULEDEF

-Item1=_DEBUG;ZLIB_DLL;Z_PREFIX;PNG_BUILD_DLL;PNG_NO_MODULEDEF

-Item2=PNG_BUILD_DLL;ZLIB_DLL;_DEBUG;PNG_NO_MODULEDEF

-Item3=PNG_BUILD_DLL;ZLIB_DLL;_DEBUG;PNG_DEBUG=5;PNG_NO_MODULEDEF;PNG_NO_GLOBAL_ARRAYS

-Item4=PNG_BUILD_DLL;ZLIB_DLL;_DEBUG;PNG_DEBUG=5;PNG_NO_MODULEDEF;PNG_SETJMP_NOT_SUPPORTED;PNG_DEBUG_FILE=stderr

-Item5=PNG_BUILD_DLL;ZLIB_DLL;_DEBUG;PNG_DEBUG;PNG_NO_MODULEDEF;PNG_SETJMP_NOT_SUPPORTED

-Item6=PNG_BUILD_DLL;ZLIB_DLL;_DEBUG;PNG_DEBUG=5;PNG_NO_MODULEDEF;PNG_SETJMP_NOT_SUPPORTED

-Item7=PNG_BUILD_DLL;ZLIB_DLL;_DEBUG;PNG_DEBUG=5;PNG_NO_MODULEDEF

-Item8=PNG_BUILD_DLL;ZLIB_DLL;_DEBUG;PNG_DEBUG=5

-Item9=PNG_BUILD_DLL;ZLIB_DLL;_DEBUG

-Item10=PNG_BUILD_DLL;ZLIB_DLL

-Item11=PNG_BUILD_DLL

-Item12=PNG_DLL;PNG_BUILD_DLL;ZLIB_DLL

-Item13=PNG_DLL;PNG_BUILD_DLL;PNG_NO_GLOBAL_ARRAYS;ZLIB_DLL

-Item14=PNG_DLL;PNG_BUILD_DLL;PNG_NO_GLOBAL_ARRAYS

-Item15=PNG_DLL;PNG_BUILD_DLL

-Item16=PNG_DLL;PNG_BUILD_DLL;PNG_MODULEDEF

-Item17=_HTML_FORM

-Item18=_DEBUG;_HTML_FORM

-Item19=_DEBUG

-

-[HistoryLists\hlIntOutputDir]

-Count=2

-Item0=..\Obj

-Item1=P:\Development\Obj

-

-[Debugging]

-DebugSourceDirs=

-

-[Parameters]

-RunParams=

-HostApplication=P:\Development\Executables\LibPNGTestApp.exe

-RemoteHost=

-RemotePath=

-RemoteDebug=0

-

-[Compiler]

-ShowInfoMsgs=0

-LinkDebugVcl=0

-LinkCGLIB=0

-  </IDEOPTIONS>

-</PROJECT>
\ No newline at end of file
diff --git a/projects/cbuilder5/libpng.cpp b/projects/cbuilder5/libpng.cpp
deleted file mode 100644
index 97865f5..0000000
--- a/projects/cbuilder5/libpng.cpp
+++ /dev/null
@@ -1,29 +0,0 @@
-//---------------------------------------------------------------------------

-#include <windows.h>

-//---------------------------------------------------------------------------

-//   Important note about DLL memory management when your DLL uses the

-//   static version of the RunTime Library:

-//

-//   If your DLL exports any functions that pass String objects (or structs/

-//   classes containing nested Strings) as parameter or function results,

-//   you will need to add the library MEMMGR.LIB to both the DLL project and

-//   any other projects that use the DLL.  You will also need to use MEMMGR.LIB

-//   if any other projects which use the DLL will be performing new or delete

-//   operations on any non-TObject-derived classes which are exported from the

-//   DLL. Adding MEMMGR.LIB to your project will change the DLL and its calling

-//   EXE's to use the BORLNDMM.DLL as their memory manager.  In these cases,

-//   the file BORLNDMM.DLL should be deployed along with your DLL.

-//

-//   To avoid using BORLNDMM.DLL, pass string information using "char *" or

-//   ShortString parameters.

-//

-//   If your DLL uses the dynamic version of the RTL, you do not need to

-//   explicitly add MEMMGR.LIB as this will be done implicitly for you

-//---------------------------------------------------------------------------

-

-int WINAPI DllEntryPoint(HINSTANCE, unsigned long, void*)

-{

-    return 1;

-}

-//---------------------------------------------------------------------------

- 
\ No newline at end of file
diff --git a/projects/cbuilder5/libpng.readme.txt b/projects/cbuilder5/libpng.readme.txt
deleted file mode 100644
index c99c1e9..0000000
--- a/projects/cbuilder5/libpng.readme.txt
+++ /dev/null
@@ -1,25 +0,0 @@
-Project files to build libpng using Borland C++ Builder v5.0
-
-In order to build and use libpng, please follow these steps:
-
- 1). Install zlib in a directory at the same level with libpng.
-
- 2). In a console window, go to the zlib directory and type:
-       make -f win32\Makefile.bor
-     After performing this step, you should have a file named
-     zlib.lib in the zlib directory.
-
- 3). Add the following conditional define to your project:
-       PNG_USE_DLL
-
- 4). Add libpng.lib or libpngstat.lib to the project.
-     Build the project.
-
- 5). If the build fails, add the paths to png.h and zlib.h to
-     your include path, and restart the build.
-
-By default, the libpng project uses zlib as a static library.  If
-you wish to use zlib as a DLL, please read the important notes from
-the zlib DLL FAQ, found inside the zlib distribution.
-
-See the libpng documentation for instructions on how to use the code.
diff --git a/projects/cbuilder5/libpngstat.bpf b/projects/cbuilder5/libpngstat.bpf
deleted file mode 100644
index f736b62..0000000
--- a/projects/cbuilder5/libpngstat.bpf
+++ /dev/null
@@ -1,22 +0,0 @@
-USEUNIT("..\..\png.c");

-USEUNIT("..\..\pngerror.c");

-USEUNIT("..\..\pngget.c");

-USEUNIT("..\..\pngmem.c");

-USEUNIT("..\..\pngpread.c");

-USEUNIT("..\..\pngread.c");

-USEUNIT("..\..\pngrio.c");

-USEUNIT("..\..\pngrtran.c");

-USEUNIT("..\..\pngrutil.c");

-USEUNIT("..\..\pngset.c");

-USEUNIT("..\..\pngtrans.c");

-USEUNIT("..\..\pngwio.c");

-USEUNIT("..\..\pngwrite.c");

-USEUNIT("..\..\pngwtran.c");

-USEUNIT("..\..\pngwutil.c");

-USELIB("..\..\..\zlib\zlib.lib");

-//---------------------------------------------------------------------------

-#define Library

-

-// To add a file to the library use the Project menu 'Add to Project'.

-

- 
\ No newline at end of file
diff --git a/projects/cbuilder5/libpngstat.bpr b/projects/cbuilder5/libpngstat.bpr
deleted file mode 100644
index 68abb8d..0000000
--- a/projects/cbuilder5/libpngstat.bpr
+++ /dev/null
@@ -1,109 +0,0 @@
-<?xml version='1.0' encoding='utf-8' ?>

-<!-- C++Builder XML Project -->

-<PROJECT>

-  <MACROS>

-    <VERSION value="BCB.05.03"/>

-    <PROJECT value="libpngstat.lib"/>

-    <OBJFILES value="..\..\pngerror.obj ..\..\png.obj ..\..\pngwutil.obj ..\..\pngmem.obj 

-      ..\..\pngpread.obj ..\..\pngread.obj ..\..\pngrio.obj ..\..\pngrtran.obj 

-      ..\..\pngrutil.obj ..\..\pngset.obj ..\..\pngtrans.obj ..\..\pngwio.obj 

-      ..\..\pngwrite.obj ..\..\pngwtran.obj ..\..\pngget.obj"/>

-    <RESFILES value=""/>

-    <DEFFILE value=""/>

-    <RESDEPEN value="$(RESFILES)"/>

-    <LIBFILES value="..\..\..\zlib\zlib.lib"/>

-    <LIBRARIES value=""/>

-    <PACKAGES value=""/>

-    <PATHCPP value=".;..\.."/>

-    <PATHPAS value=".;"/>

-    <PATHRC value=".;"/>

-    <PATHASM value=".;"/>

-    <LINKER value="TLib"/>

-    <USERDEFINES value=""/>

-    <SYSDEFINES value="_RTLDLL;NO_STRICT"/>

-    <MAINSOURCE value="libpngstat.bpf"/>

-    <INCLUDEPATH value="..\..;..\..\..\zlib;$(BCB)\include"/>

-    <LIBPATH value="..\..;$(BCB)\lib\obj;$(BCB)\lib"/>

-    <WARNINGS value="-w-par"/>

-    <LISTFILE value=""/>

-  </MACROS>

-  <OPTIONS>

-    <CFLAG1 value="-O2 -w -Vx -Ve -X- -a8 -5 -b- -d -k- -vi -c -tW -tWM"/>

-    <PFLAGS value="-$Y- -$L- -$D- -$C- -v -JPHNE -M"/>

-    <AFLAGS value="/mx /w2 /zn"/>

-    <LFLAGS value=""/>

-  </OPTIONS>

-  <LINKER>

-    <ALLOBJ value="$(OBJFILES)"/>

-    <ALLLIB value=""/>

-  </LINKER>

-  <IDEOPTIONS>

-[Version Info]

-IncludeVerInfo=0

-AutoIncBuild=0

-MajorVer=1

-MinorVer=0

-Release=0

-Build=0

-Debug=0

-PreRelease=0

-Special=0

-Private=0

-DLL=0

-Locale=2057

-CodePage=1252

-

-[Version Info Keys]

-CompanyName=

-FileDescription=

-FileVersion=1.0.0.0

-InternalName=

-LegalCopyright=

-LegalTrademarks=

-OriginalFilename=

-ProductName=

-ProductVersion=1.0.0.0

-Comments=

-

-[HistoryLists\hlIncludePath]

-Count=2

-Item0=..\..;P:\My Documents\Source\PNG+ZLib\zlib;$(BCB)\include

-Item1=..\..;$(BCB)\include;$(BCB)\include\vcl

-

-[HistoryLists\hlLibraryPath]

-Count=1

-Item0=..\..;$(BCB)\lib\obj;$(BCB)\lib

-

-[HistoryLists\hlDebugSourcePath]

-Count=1

-Item0=$(BCB)\source\vcl

-

-[HistoryLists\hlConditionals]

-Count=1

-Item0=_DEBUG

-

-[HistoryLists\hlTlibPageSize]

-Count=1

-Item0=0x0010

-

-[Debugging]

-DebugSourceDirs=$(BCB)\source\vcl

-

-[Parameters]

-RunParams=

-HostApplication=

-RemoteHost=

-RemotePath=

-RemoteDebug=0

-

-[Compiler]

-ShowInfoMsgs=0

-LinkDebugVcl=0

-LinkCGLIB=0

-

-[Language]

-ActiveLang=

-ProjectLang=

-RootDir=

-  </IDEOPTIONS>

-</PROJECT>
\ No newline at end of file
diff --git a/projects/cbuilder5/zlib.readme.txt b/projects/cbuilder5/zlib.readme.txt
deleted file mode 100644
index cb6a7a8..0000000
--- a/projects/cbuilder5/zlib.readme.txt
+++ /dev/null
@@ -1,14 +0,0 @@
-The project that builds libpng under Borland C++ Builder does not
-explicitly build zlib.  By taking this decision, there is no need
-to update the libpng project each time when there is a change in
-the list of zlib source files.  After all, this list is private to
-zlib, and applications (such as libpng) should not assume anything
-about it.
-
-If you wish to contribute a project that builds zlib under Borland
-C++ Builder, please submit it to the zlib developers, not to the
-libpng developers.
-
-By default, the libpng project uses zlib as a static library.  If
-you wish to use zlib as a DLL, please read the important notes from
-the zlib DLL FAQ, found inside the zlib distribution.
diff --git a/projects/xcode/libpng.xcodeproj/project.pbxproj b/projects/xcode/libpng.xcodeproj/project.pbxproj
index 0d6324e..81e99b8 100644
--- a/projects/xcode/libpng.xcodeproj/project.pbxproj
+++ b/projects/xcode/libpng.xcodeproj/project.pbxproj
@@ -226,7 +226,7 @@
 				COPY_PHASE_STRIP = NO;
 				DYLIB_COMPATIBILITY_VERSION = 14;
 				DYLIB_CURRENT_VERSION = 14;
-				FRAMEWORK_VERSION = 1.4.1beta10;
+				FRAMEWORK_VERSION = 1.4.1beta11;
 				GCC_PRECOMPILE_PREFIX_HEADER = NO;
 				GCC_PREFIX_HEADER = "";
 				INFOPLIST_FILE = Info.plist;
@@ -244,7 +244,7 @@
 			buildSettings = {
 				DYLIB_COMPATIBILITY_VERSION = 14;
 				DYLIB_CURRENT_VERSION = 14;
-				FRAMEWORK_VERSION = 1.4.1beta10;
+				FRAMEWORK_VERSION = 1.4.1beta11;
 				GCC_PRECOMPILE_PREFIX_HEADER = NO;
 				GCC_PREFIX_HEADER = "";
 				INFOPLIST_FILE = Info.plist;
diff --git a/scripts/README.txt b/scripts/README.txt
index d98e4de..25e8184 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,8 +1,8 @@
 
-Makefiles for  libpng version 1.4.1beta10 - February 8, 2010
+Makefiles for  libpng version 1.4.1beta11 - February 13, 2010
 
  makefile.linux    =>  Linux/ELF makefile
-                       (gcc, creates libpng14.so.14.1.4.1beta10)
+                       (gcc, creates libpng14.so.14.1.4.1beta11)
  makefile.gcc      =>  Generic makefile (gcc, creates static libpng.a)
  makefile.knr      =>  Archaic UNIX Makefile that converts files with
                        ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@
  makefile.dec      =>  DEC Alpha UNIX makefile
  makefile.dj2      =>  DJGPP 2 makefile
  makefile.elf      =>  Linux/ELF makefile symbol versioning,
-                       gcc, creates libpng14.so.14.1.4.1beta10)
+                       gcc, creates libpng14.so.14.1.4.1beta11)
  makefile.freebsd  =>  FreeBSD makefile
  makefile.gcc      =>  Generic gcc makefile
  makefile.hpgcc    =>  HPUX makefile using gcc
@@ -36,12 +36,12 @@
  makefile.os2      =>  OS/2 Makefile (gcc and emx, requires pngos2.def)
  makefile.sco      =>  For SCO OSr5  ELF and Unixware 7 with Native cc
  makefile.sggcc    =>  Silicon Graphics (gcc,
-                       creates libpng14.so.14.1.4.1beta10)
+                       creates libpng14.so.14.1.4.1beta11)
  makefile.sgi      =>  Silicon Graphics IRIX makefile (cc, creates static lib)
  makefile.solaris  =>  Solaris 2.X makefile (gcc,
-                       creates libpng14.so.14.1.4.1beta10)
+                       creates libpng14.so.14.1.4.1beta11)
  makefile.so9      =>  Solaris 9 makefile (gcc,
-                       creates libpng14.so.14.1.4.1beta10)
+                       creates libpng14.so.14.1.4.1beta11)
  makefile.std      =>  Generic UNIX makefile (cc, creates static libpng.a)
  makefile.sunos    =>  Sun makefile
  makefile.32sunu   =>  Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 82e5a69..9026a40 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
 
 # Modeled after libxml-config.
 
-version=1.4.1beta10
+version=1.4.1beta11
 prefix=""
 libdir=""
 libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 042303f..ef1c127 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@
 
 Name: libpng
 Description: Loads and saves PNG files
-Version: 1.4.1beta10
+Version: 1.4.1beta11
 Libs: -L${libdir} -lpng14
 Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index e50cae1..0f009d3 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@
 
 LIB=	png14
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.4.1beta10
+SHLIB_MINOR=	1.4.1beta11
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 0d680f3..41c0b64 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@
 
 LIB=	png
 SHLIB_MAJOR=	3
-SHLIB_MINOR=	1.4.1beta10
+SHLIB_MINOR=	1.4.1beta11
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index b361a29..dbed3af 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@
 MANDIR= ${PREFIX}/man/cat
 
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.4.1beta10
+SHLIB_MINOR=	1.4.1beta11
 
 LIB=	png
 SRCS=	png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/png32ce.def b/scripts/png32ce.def
index 9fdfffc..216d00e 100644
--- a/scripts/png32ce.def
+++ b/scripts/png32ce.def
@@ -15,7 +15,7 @@
  png_get_int_32
 
 EXPORTS
-;Version 1.4.1beta10
+;Version 1.4.1beta11
   png_build_grayscale_palette  @1
 ;  png_check_sig        @2
   png_chunk_error      @3
diff --git a/scripts/pngos2.def b/scripts/pngos2.def
index 8f85a47..05453ec 100644
--- a/scripts/pngos2.def
+++ b/scripts/pngos2.def
@@ -2,7 +2,7 @@
 ; PNG.LIB module definition file for OS/2
 ;----------------------------------------
 
-; Version 1.4.1beta10
+; Version 1.4.1beta11
 
 LIBRARY		PNG
 DESCRIPTION	"PNG image compression library for OS/2"
diff --git a/scripts/pngwin.def b/scripts/pngwin.def
index eee1728..3c655f5 100644
--- a/scripts/pngwin.def
+++ b/scripts/pngwin.def
@@ -5,7 +5,7 @@
 LIBRARY
 
 EXPORTS
-;Version 1.4.1beta10
+;Version 1.4.1beta11
   png_build_grayscale_palette
   png_chunk_error
   png_chunk_warning
diff --git a/png.c b/png.c
index da7863f..4d2d9bd 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
 
 /* png.c - location for general purpose libpng functions
  *
  * Last changed in libpng 1.4.1 [February 8, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -17,7 +17,7 @@
 #include "pngpriv.h"
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_1beta10 Your_png_h_is_not_version_1_4_1beta10;
+typedef version_1_4_1beta11 Your_png_h_is_not_version_1_4_1beta11;
 
 /* Version information for C files.  This had better match the version
  * string defined in png.h.
@@ -551,13 +551,13 @@
 #else
 #ifdef __STDC__
    return ((png_charp) PNG_STRING_NEWLINE \
-     "libpng version 1.4.1beta10 - February 8, 2010" PNG_STRING_NEWLINE \
+     "libpng version 1.4.1beta11 - February 13, 2010" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2010 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE);
 #else
-      return ((png_charp) "libpng version 1.4.1beta10 - February 8, 2010\
+      return ((png_charp) "libpng version 1.4.1beta11 - February 13, 2010\
       Copyright (c) 1998-2010 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
@@ -1,7 +1,7 @@
 /* png.c - location for general purpose libpng functions
  *
- * Last changed in libpng 1.4.1 [February 8, 2010]
+ * Last changed in libpng 1.4.1 [February 13, 2010]
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/png.h b/png.h
index 87c9a10..868c99b 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.4.1beta10 - February 8, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.4.1beta10 - February 8, 2010: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -168,7 +168,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.4.1beta10, February 8, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -280,13 +280,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    February 8, 2010
+ *    February 13, 2010
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.4.1beta10 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -342,9 +342,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.1beta10"
+#define PNG_LIBPNG_VER_STRING "1.4.1beta11"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.4.1beta10 - February 8, 2010\n"
+   " libpng version 1.4.1beta11 - February 13, 2010\n"
 
 #define PNG_LIBPNG_VER_SONUM   14
 #define PNG_LIBPNG_VER_DLLNUM  14
@@ -357,7 +357,7 @@
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
 
-#define PNG_LIBPNG_VER_BUILD  10
+#define PNG_LIBPNG_VER_BUILD  11
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -1470,7 +1470,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef png_structp version_1_4_1beta10;
+typedef png_structp version_1_4_1beta11;
 
 typedef png_struct FAR * FAR * png_structpp;
 
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.4.1beta10 - February 8, 2010
+ * libpng version 1.4.1beta11 - February 13, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.4.1beta10 - February 8, 2010: Glenn
+ *  libpng versions 0.97, January 1998, through 1.4.1beta11 - February 13, 2010: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -168,7 +168,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.4.1beta10, February 8, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.1beta11, February 13, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -280,13 +280,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.4.1beta10 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.4.1beta11 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *